API docs for “spamfighter.txjsonrpc.web.jsonrpc.Proxy”

# Class s.t.w.j.Proxy:

Part of spamfighter.txjsonrpc.web.jsonrpc View Source View In Hierarchy

A Proxy for making remote JSON-RPC calls.

Pass the URL of the remote JSON-RPC server to the constructor.

Use proxy.callRemote('foobar', *args) to call remote method 'foobar' with *args.

Method | __init__ |
Method | callRemote | Undocumented

def __init__(self, url, user=None, password=None): (source)

Parameters | url | The URL to which to post method calls. Calls will be made over SSL if the scheme is HTTPS. If netloc contains username or password information, these will be used to authenticate, as long as the `user` and `password` arguments are not specified. (type: `str` )
| user | The username with which to authenticate with the server when making calls. If specified, overrides any username information embedded in `url`. If not specified, a value may be taken from `url` if present. (type: `str` or None )
| password | The password with which to authenticate with the server when making calls. If specified, overrides any password information embedded in `url`. If not specified, a value may be taken from `url` if present. (type: `str` or None )

def callRemote(self, method, *args): (source)
Undocumented